==> haskell-xcffib-1.6.1-8.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xcffib
version:              1.6.1
visibility:           public
id:                   xcffib-1.6.1-55OcuhzDnuY3IRzCiPYIl3
key:                  xcffib-1.6.1-55OcuhzDnuY3IRzCiPYIl3
license:              Apache-2.0
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  664082259dd2b4daa2cf1714ea88e683
exposed:              True
exposed-modules:
    Data.XCB.Python.AST Data.XCB.Python.Parse Data.XCB.Python.PyHelpers

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.6.1-55OcuhzDnuY3IRzCiPYIl3
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    either-5.0.3-LXBywpYsrH13GkjtmaGjK1
    filemanip-0.3.6.3-6V4CNJFHbtkIqz2ftt7SXD filepath-1.4.300.1
    mtl-2.3.1 pretty-1.1.3.6 split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    xcb-types-0.15.0-6z9EOxYPeI87mDQie0Oecz

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-1.6.1-9-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xcffib
version:              1.6.1
visibility:           public
id:                   xcffib-1.6.1-4v4akGeKKsLDZDpFDqJIxJ
key:                  xcffib-1.6.1-4v4akGeKKsLDZDpFDqJIxJ
license:              Apache-2.0
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  5865a71d5b72fd3bf24ae1fcbf6ffd8a
exposed:              True
exposed-modules:
    Data.XCB.Python.AST Data.XCB.Python.Parse Data.XCB.Python.PyHelpers

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.6.1-4v4akGeKKsLDZDpFDqJIxJ
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    either-5.0.3-AwsJObJJa5t15rwL7Wjn2s
    filemanip-0.3.6.3-ZKF7Yf0QS1DhtpRpoSM7p filepath-1.4.300.1
    mtl-2.3.1 pretty-1.1.3.6 split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    xcb-types-0.15.0-6z9EOxYPeI87mDQie0Oecz

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
